/*
 * $LastChangedRevision: 903 $
 * $LastChangedDate:: 2016-03-10 14:44:32 +0100#$
 *
 * Copyright (c) 2013, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 */
#include "dmtimer.h"
#include "interrupt.h"

#include "Target.h"
#include "Main.h"
#include "Hardware.h"

/**
 * Sample time @ timer clock = 24 MHz.
 */
#define SAMPLETIME_100US (2400)
#define SAMPLETIME_50US (1200)
#define SAMPLETIME_20US (480)
#define SAMPLETIME_10US (240)

#define SELECTED_SAMPLETIME		SAMPLETIME_100US

#define TIMER_INITIAL_COUNT ((uint32)0xFFFFFFFF - SELECTED_SAMPLETIME)
#define TIMER_RLD_COUNT ((uint32)0xFFFFFFFF - SELECTED_SAMPLETIME)

/* private prototypes */
static void setupTimer(void);
static void DMTimerIsr(void);

void initHardware(void)
{
	GPIO1ModuleClkConfig();
	GPIO1Pin23PinMuxSetup();
	GPIOModuleEnable(SOC_GPIO_1_REGS);
	GPIOModuleReset(SOC_GPIO_1_REGS);
	GPIODirModeSet(SOC_GPIO_1_REGS, 23, GPIO_DIR_OUTPUT);

    setupTimer();

    /* Enable IRQ in CPSR */
    IntMasterIRQEnable();

    /* Registering DMTimerIsr */
    IntRegister(SYS_INT_TINT2, DMTimerIsr);

    /* Set the priority */
    IntPrioritySet(SYS_INT_TINT2, 0, AINTC_HOSTINT_ROUTE_IRQ);

    /* Enable the system interrupt */
    IntSystemEnable(SYS_INT_TINT2);

    /* Start the DMTimer */
    DMTimerEnable(SOC_DMTIMER_2_REGS);

    /* Start the DMTimer */
    DMTimerEnable(SOC_DMTIMER_2_REGS);
}

static void setupTimer(void)
{
    /* This function will enable clocks for the DMTimer2 instance */
    DMTimer2ModuleClkConfig();

    /* Load the counter with the initial count value */
    DMTimerCounterSet(SOC_DMTIMER_2_REGS, TIMER_INITIAL_COUNT);

    /* Load the load register with the reload count value */
    DMTimerReloadSet(SOC_DMTIMER_2_REGS, TIMER_RLD_COUNT);

    /* Configure the DMTimer for Auto-reload and compare mode */
    DMTimerModeConfigure(SOC_DMTIMER_2_REGS, DMTIMER_AUTORLD_NOCMP_ENABLE);

    /* Enable the DMTimer interrupts */
    DMTimerIntEnable(SOC_DMTIMER_2_REGS, DMTIMER_INT_OVF_EN_FLAG);
}

static void DMTimerIsr(void)
{
    /* Disable the DMTimer interrupts */
//    DMTimerIntDisable(SOC_DMTIMER_2_REGS, DMTIMER_INT_OVF_EN_FLAG);

    /* Clear the status of the interrupt flags */
    DMTimerIntStatusClear(SOC_DMTIMER_2_REGS, DMTIMER_INT_OVF_IT_FLAG);

    mainTask();

    /* Enable the DMTimer interrupts */
//    DMTimerIntEnable(SOC_DMTIMER_2_REGS, DMTIMER_INT_OVF_EN_FLAG);
}
