// Copyright (c) 2014, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
// All rights reserved.
//
// This file is licensed according to the BSD 3-clause license as follows:
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright
//       notice, this list of conditions and the following disclaimer in the
//       documentation and/or other materials provided with the distribution.
//     * Neither the name of the "Linz Center of Mechatronics GmbH" and "LCM" nor
//       the names of its contributors may be used to endorse or promote products
//       derived from this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
// IN NO EVENT SHALL "Linz Center of Mechatronics GmbH" BE LIABLE FOR ANY
// DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

mode(-1);
lines(0);

function main_builder()

    TOOLBOX_NAME  = "x2c";
    TOOLBOX_TITLE = "Rich toolset for rapid prototyping ";
    toolbox_dir   = get_absolute_file_path("builder.sce");

    // Check Scilab's version
    // =============================================================================

    // check minimal version (xcosPal required)
    if ~isdef("xcosPal") then
        // and xcos features required
        error(gettext("Scilab 5.3.2 or more is required."));
    end

    // Check modules_manager module availability
    // =============================================================================

    if ~isdef("tbx_build_loader") then
        error(msprintf(gettext("%s module not installed."), "modules_manager"));
    end

    // Action
    // =============================================================================
    // On linux, the user must first set an "X2C_Root" environment variable
    if getos() == "Linux" then
        try
            getenv("X2C_Root");
        catch
            error("X2C_Root environment variable not defined, please refer to http://www.mechatronic-simulation.org/support/faq/\n");
        end
    end
    X2C_Root = get_absolute_file_path("builder.sce");
    libraryDir = X2C_Root + "Library/";
    systemDir = X2C_Root + "System/";
    // Run the actual setup
    exec(systemDir + "Scilab/Scripts/setupSU.sce");
    if getos() == "Linux" then
        compileLibs();
    end
    // Generate lib files for macros
    genlib("X2Clib", X2C_Root + "macros", %F, %T);
    genlib("systemlib", systemDir + "Scilab/Scripts", %F, %T);
    genlib("x2cBasiclib", libraryDir + "Basic/Scilab", %F, %T);
    genlib("x2cControllib", libraryDir + "Control/Scilab", %F, %T);
    genlib("x2cGenerallib", libraryDir + "General/Scilab", %F, %T);
    genlib("x2cMathlib", libraryDir + "Math/Scilab", %F, %T);

    // Modify the generated scilab_x2c.ini script to add a recognizable pattern "|tbx_path|"
    // that will be updated at load-time. Also, add a message to let the user know that his Scilab
    // needs to be restarted the first time he loads X2C.
    // Finally, move the file inside the toolbox for portability.
    fd = mopen("SCIHOME/scilab_x2c.ini", "r");
    txt = mgetl(fd);
    mclose(fd);
    deletefile("SCIHOME/scilab_x2c.ini");
    // Use a special string "|tbx_path|" to find it
    newTxt = strsubst(txt, X2C_Root, "|tbx_path|");
    // The first load will need to restart Scilab
    newTxt = strsubst(newTxt, "x2c_LibManager_populate();", "try x2c_LibManager_populate(); catch mprintf(""\n\n  Environment set, please restart Scilab to use X2C!\n\n""); abort; end");
    fd2 = mopen(X2C_Root + "etc/scilab_x2c.ini", "w");
    mputl(newTxt, fd2);
    mclose(fd2);

    // Generate loader & cleaner
    tbx_build_loader(TOOLBOX_NAME, toolbox_dir);
    tbx_build_cleaner(TOOLBOX_NAME, toolbox_dir);

endfunction

if with_module("xcos") then
    main_builder();
    clear main_builder; // remove main_builder on stack
end
